==> eam-wshub-proxyclient-11.6-2-sources.jar: net/datastream/schemas/mp_results/mp7925_001/MP7925_GetWorkOrderSchedule_001_Result.java <==

package net.datastream.schemas.mp_results.mp7925_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.workorderschedule_002.WorkOrderSchedule;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="ResultData">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 &lt;sequence>
 *                   &lt;element ref="{http://schemas.datastream.net/MP_entities/WorkOrderSchedule_002}WorkOrderSchedule"/>
 *                 &lt;/sequence>
 *               &lt;/restriction>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "resultData"
})
@XmlRootElement(name = "MP7925_GetWorkOrderSchedule_001_Result")
public class MP7925_GetWorkOrderSchedule_001_Result {

    @XmlElement(name = "ResultData", required = true)
    protected MP7925_GetWorkOrderSchedule_001_Result.ResultData resultData;

    /**
     * Obtient la valeur de la propriété resultData.
     * 
     * @return
     *     possible object is
     *     {@link MP7925_GetWorkOrderSchedule_001_Result.ResultData }
     *     
     */
    public MP7925_GetWorkOrderSchedule_001_Result.ResultData getResultData() {
        return resultData;
    }

    /**
     * Définit la valeur de la propriété resultData.
     * 
     * @param value
     *     allowed object is
     *     {@link MP7925_GetWorkOrderSchedule_001_Result.ResultData }
     *     
     */
    public void setResultData(MP7925_GetWorkOrderSchedule_001_Result.ResultData value) {
        this.resultData = value;
    }


    /**
     * <p>Classe Java pour anonymous complex type.
     * 
     * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;sequence>
     *         &lt;element ref="{http://schemas.datastream.net/MP_entities/WorkOrderSchedule_002}WorkOrderSchedule"/>
     *       &lt;/sequence>
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "workOrderSchedule"
    })
    public static class ResultData {

        @XmlElement(name = "WorkOrderSchedule", namespace = "http://schemas.datastream.net/MP_entities/WorkOrderSchedule_002", required = true)
        protected WorkOrderSchedule workOrderSchedule;

        /**
         * Obtient la valeur de la propriété workOrderSchedule.
         * 
         * @return
         *     possible object is
         *     {@link WorkOrderSchedule }
         *     
         */
        public WorkOrderSchedule getWorkOrderSchedule() {
            return workOrderSchedule;
        }

        /**
         * Définit la valeur de la propriété workOrderSchedule.
         * 
         * @param value
         *     allowed object is
         *     {@link WorkOrderSchedule }
         *     
         */
        public void setWorkOrderSchedule(WorkOrderSchedule value) {
            this.workOrderSchedule = value;
        }

    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_results/mp7925_001/MP7925_GetWorkOrderSchedule_001_Result.java <==

package net.datastream.schemas.mp_results.mp7925_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.workorderschedule_002.WorkOrderSchedule;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="ResultData">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 &lt;sequence>
 *                   &lt;element ref="{http://schemas.datastream.net/MP_entities/WorkOrderSchedule_002}WorkOrderSchedule"/>
 *                 &lt;/sequence>
 *               &lt;/restriction>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "resultData"
})
@XmlRootElement(name = "MP7925_GetWorkOrderSchedule_001_Result")
public class MP7925_GetWorkOrderSchedule_001_Result {

    @XmlElement(name = "ResultData", required = true)
    protected MP7925_GetWorkOrderSchedule_001_Result.ResultData resultData;

    /**
     * Gets the value of the resultData property.
     * 
     * @return
     *     possible object is
     *     {@link MP7925_GetWorkOrderSchedule_001_Result.ResultData }
     *     
     */
    public MP7925_GetWorkOrderSchedule_001_Result.ResultData getResultData() {
        return resultData;
    }

    /**
     * Sets the value of the resultData property.
     * 
     * @param value
     *     allowed object is
     *     {@link MP7925_GetWorkOrderSchedule_001_Result.ResultData }
     *     
     */
    public void setResultData(MP7925_GetWorkOrderSchedule_001_Result.ResultData value) {
        this.resultData = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;sequence>
     *         &lt;element ref="{http://schemas.datastream.net/MP_entities/WorkOrderSchedule_002}WorkOrderSchedule"/>
     *       &lt;/sequence>
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "workOrderSchedule"
    })
    public static class ResultData {

        @XmlElement(name = "WorkOrderSchedule", namespace = "http://schemas.datastream.net/MP_entities/WorkOrderSchedule_002", required = true)
        protected WorkOrderSchedule workOrderSchedule;

        /**
         * Gets the value of the workOrderSchedule property.
         * 
         * @return
         *     possible object is
         *     {@link WorkOrderSchedule }
         *     
         */
        public WorkOrderSchedule getWorkOrderSchedule() {
            return workOrderSchedule;
        }

        /**
         * Sets the value of the workOrderSchedule property.
         * 
         * @param value
         *     allowed object is
         *     {@link WorkOrderSchedule }
         *     
         */
        public void setWorkOrderSchedule(WorkOrderSchedule value) {
            this.workOrderSchedule = value;
        }

    }

}
